/*
 * @Fluid_Map.java Version 1.1 10/01/2003
 *
 * Copyright (c) 2001 Kansas Geological Survey
 * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
 * All Rights Reserved.
 */

import java.io.*;
import java.net.*;
import java.awt.*;
import java.awt.event.*;
import java.applet.*;
import javax.swing.*;

import grid.gridStruct;
import grid.gridDataStruct;
import grid.gui.gridStartAppPanel;

/** Class Fluid_Map
 *  <p> This Class is the starting point for the Web Fluid_Map Viewer
 *      Module.  This module will assist the user in building a Well Header
 *      Information XML File from wells that are available on the Server
 *
 *  @version 1.1 10/01/2003
 *  @author  John R. Victorine
 */

public class Fluid_Map extends JApplet
{
  private boolean        isStandalone = false;
  private gridStruct     stStruct     = new gridStruct();
  private gridDataStruct stData       = null;

  private String         sID          = "FLUID";

  /** getParameter()
   *  <p> This method wil get a parameter value
   *  @param  key = The Name of the Parameter
   *  @param  def = The Object Type of the Parameter
   *  @return the String defined by key
   */

  public String getParameter(String key, String def)
  {
    return (isStandalone ? System.getProperty(key, def) :
            (getParameter(key) != null ? getParameter(key) : def));
  }

  /** Constructor Well Profile
   *  <p> This is the Constructor for this class.
   */

  public Fluid_Map() {  }

  /** Method init()
   *  <p> This Method will retrieve the data values from the HTML or the main()
   *      arguments and run the Formation Viewer Module.
   */

  public void init()
  {
    try
    {
      jbInit();
    }
    catch(Exception e)
    {
      e.printStackTrace();
      String sMessage = new String(
          "Problem Creating the Gridding And Mapping Dialog " + e.getMessage());
      JOptionPane.showMessageDialog((Component) null,
                                     sMessage,
                                     "ERROR",
                                     JOptionPane.ERROR_MESSAGE);
    }
  }

  /** Method jbInit()
   *  <p> This method will display the Gridding and Mapping Screens.
   * @throws Exception
   */

  private void jbInit() throws Exception
  {
    gridStartAppPanel panel = null;
    String            sPath = "";

    stStruct.bStandalone = isStandalone;

    stData            = new gridDataStruct();
    stData.stWellList = grid.io.gridIORead.readWellData();
    stData.stFluid    = grid.io.gridIORead.readFluidLevelData();
    stData            = grid.gridDataUtility.loadGriddingParametersData( stData );

//fluid.fluidUtility.print(stData.stFluid);

    if (!isStandalone)
    {
      stStruct.urlDirCodeBase = getCodeBase();
      stStruct.appletContext  = getAppletContext();
      stStruct.pIcon          = getImage(getCodeBase(), grid.gridStruct.ICON);
      stStruct.pIcon2         = getImage(getCodeBase(), grid.gridStruct.ICON2);
    }
    else
    {
      URL url = null;

      stStruct.urlDirCodeBase =  getClass().getClassLoader().getResource(".");

      ClassLoader cl = this.getClass().getClassLoader();
      sPath = cl.getResource("images").toString();
      stStruct.sImagePath = new String(sPath);

      try
      {
        url = new URL(sPath+"\\kgsSm.png");
        stStruct.pIcon = Toolkit.getDefaultToolkit().getImage(url);
        url = new URL(sPath+"\\kgsSm2.png");
        stStruct.pIcon2 = Toolkit.getDefaultToolkit().getImage(url);
      }
      catch (java.net.MalformedURLException e)
      {
        e.printStackTrace();
        String sMessage = new String("Fluid_Map.jbInit(): \n" +
                              e.getMessage() + "\n" +
                              "Couldn't create image: " + sPath+"\\kgsSm.gif");
        JOptionPane.showMessageDialog((Component) null,
                                      sMessage,
                                      "ERROR",
                                      JOptionPane.ERROR_MESSAGE);
      }
    }

    // Get the Path of the XML Files stored in JAR File.

    ClassLoader cl   = this.getClass().getClassLoader();
//    sPath            = cl.getResource("data").toString();
//    stStruct.sPath      = new String(sPath);

    sPath               = cl.getResource("images").toString();
    stStruct.sImagePath = new String(sPath);
    stStruct.cl         = cl;

    // Display the LAS Viewer Start

    if (!isStandalone)
    {
      panel = new gridStartAppPanel( sID, null, stStruct, stData );

      this.setLayout(new BorderLayout());
      this.add(panel, BorderLayout.CENTER);
    }
    else
    {
      JFrame frame = new JFrame();

      frame.setTitle("SELECT");
      panel = new gridStartAppPanel( sID, frame, stStruct, stData );
      frame.getContentPane().add(panel, null);

      // Set the Size and Display the Frame

      frame.setSize(300, 300);
      Dimension d = Toolkit.getDefaultToolkit().getScreenSize();
      frame.setLocation((d.width - frame.getSize().width)/2,
                        (d.height - frame.getSize().height)/2);

      frame.setResizable(false);
      frame.setVisible(true);
    }
  }

  /** Method start()
   *  <p> This method will start the applet
   */

  public void start() { }

  /** Method stop()
   *  <p> This method will stop the applet
   */

  public void stop() { }

  /** Method destroy()
   *  <p> This method will destroy the applet
   */

  public void destroy() { }

  /** Method getAppletInfo()
   *  <p> This method will return Applet information
   *  @return - Applet Information
   */

  public String getAppletInfo() { return "Gridding And Mapping"; }

  /** Method getParameterInfo()
   *  <p> This method will get the parameter info
   *  @return pinfo - Array of Parameters Expected.
   */

  public String[][] getParameterInfo()
  {
    String[][] pinfo =  {  };

    return pinfo;
  }

  /** Method main()
   *  <p> This method will allow this Module to run either as an Application or
   *      an Applet.
   * @param args = Array of arguments passed to this application (NOT USED)
   */

  public static void main(String[] args)
  {
    Fluid_Map applet = new Fluid_Map();

    applet.isStandalone = true;
    applet.init();
    applet.start();
  }
}