/*
 * @gridDataStruct.java Version 1.1 06/25/2015
 *
 * Copyright (c) 2015 Kansas Geological Survey
 * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
 * All Rights Reserved.
 */

package grid;

import iqstrat.iqstratHeadersListStruct; // Well Header List Data Structure
import fluid.fluidListStruct;            // Fluid Level Data List Structure
import brine.brineListStruct;            // Brine Data List Structure
import grid.math.gridParametersStruct;   // Grid Parameters Data Structure

/** Class gridDataStruct
 *  <p> This Class holds the possible selections from the KGS DB
 *
 *  @version 1.1 06/25/2015
 *  @author  John R. Victorine
 */

public class gridDataStruct
{
  public static final int UTM_X  = 0;
  public static final int UTM_Y  = 1;
  public static final int DATA_R = 2;
  public static final int DATA_G = 3;
  public static final int DATA_B = 4;

  // Data Structures used for the Gridding & Mapping Module
  // -- Well Header Information List Data Structure

  public iqstratHeadersListStruct stWellList = null;

  // -- Fluid Level List Data Structure

  public fluidListStruct          stFluid    = null;

  // -- Brine List Data Structure

  public brineListStruct          stBrine    = null;

  public String                   search     = null;

  // -- Gridding Parameters Data Structure

  public gridParametersStruct     stGrid     = null;

  // -- Data to be mapped List

 // public gridMapDataListStruct    stDataList = null;

  // Gridding & Mapping Data for Wells

  public int    iRows       = 0;    // Total Number of Wells used
  public String sAPI[]      = null; // API-Number of Wells
  public String status[]    = null; // Status of Wells
  public String sName[]     = null; // Lease Name of Well
  public int    iTriangle[] = null; // Zone has been perforated.
  public double dX[]        = null; // Relative UTM-X Position
  public double dY[]        = null; // Relative UTM-Y Position
  public double dZR[]       = null; // User Entered Data - Red Color
  public double dZG[]       = null; // User Entered Data - Green Color
  public double dZB[]       = null; // User Entered Data - Blue Color

  /** Method delete()
   * <p> This method will set the Object Variables to null to force Java
   *     to free memory.
   */

  public void delete()
  {
    // Data Structures used for the Gridding & Mapping Module
    // -- Well Header Information List Data Structure

    if (stWellList != null)
      stWellList.delete();
    stWellList = null;

    // -- Gridding Parameters Data Structure

    if (stGrid != null)
      stGrid.delete();
    stGrid     = null; //new gridParametersStruct();

    // -- Data to be mapped List

//    if (stDataList != null)
//      stDataList.delete();
//    stDataList = new gridMapDataListStruct();

    // Search Parameter Data

    search    = null;

    // Gridding & Mapping Data for Wells

    iRows     = 0;    // Total Number of Wells used
    sAPI      = null; // API-Number of Wells
    status    = null; // Status of Wells
    sName     = null; // Lease Name of Well
    iTriangle = null; // Zone has been perforated.
    dX        = null; // Relative UTM-X Position
    dY        = null; // Relative UTM-Y Position
    dZR       = null; // User Entered Data - Red   Color
    dZG       = null; // User Entered Data - Green Color
    dZB       = null; // User Entered Data - Blue  Color
  }

  /** Method getData()
   * <p> This method will return the data array requested.
   * @param  iType = The Type of Data requested
   * @return number data array
   */

  public double[] getData(int iType)
  {
    double dValue[] = null;

    switch (iType)
    {
      case UTM_X:    // UTM X-Position RETURN dX[]
        dValue = dX;
        break;

      case UTM_Y:    // UTM Y-Position RETURN dY[]
        dValue = dY;
        break;

      case DATA_R:    // User Data Array RETURN Red dZ[]
        dValue = dZR;
        break;

      case DATA_G:    // User Data Array RETURN Green dZ[]
        dValue = dZG;
        break;

      case DATA_B:    // User Data Array RETURN Blue dZ[]
        dValue = dZB;
        break;
    }

    return (dValue);
  }
}


/*
 *  @version 1.1 06/25/2015
 *  @author  John Victorine
 */
