/*
 * @gridAvgTable.java Version 1.1 07/06/2015
 *
 * Copyright (c) 2001 Kansas Geological Survey
 * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
 * All Rights Reserved.
 */

package grid.gui;

import java.awt.*;
import java.awt.event.*;
import java.lang.*;
import javax.swing.*;
import javax.swing.border.*;
import javax.swing.event.*;
import javax.swing.table.*;

import gui.guiTable;

/** Class gridAvgTable
 *  <p> This Class will display the Curve Data.
 *
 *  @version 1.1 07/06/2015
 *  @author  John R. Victorine
 */

public class gridAvgTable
{
  private String    sMessage  = "";
  private int       iRows     = 0;
  private int       iColumns  = 9;
  private String    sColumn[] = { "MNEM", "Min",  "5%",  "25%", "Mean",
                                          "Median", "75%", "95%", "Max" };
  private int       iLength[] = { 8, 8, 8, 8, 8, 8, 8, 8, 8 };
  private Object    oData[][] = null;
  private guiTable  pTable    = null;

  /** Constructor gridAvgTable()
   *  <p> This is the Constructor for this class.
   */

  public gridAvgTable()
  {
    pTable = new guiTable(0, iColumns, sColumn);

//    resetColumnWidths();
//    pTable.showHorScroll(true);
  }

  /** Method resetColumnWidths()
   *  <p> This method will reset the column widths to a specific size.
   */

  private void resetColumnWidths()
  {
    for (int i=0; i<iColumns; i++)
    {
      pTable.resizeColumn(i, iLength[i]);
    }
  }

  /** Method close()
   *  <p> This method will force Java to deallocate the memory
   */

  public void close()
  {
    sMessage = "";
    sColumn  = null;
    iLength  = null;
    oData    = null;
    pTable.close();
    pTable = null;
  }

  /* ===================================================================== *
   * -------------------------- SET METHODS ------------------------------ *
   * ===================================================================== */

  /** Method clear()
   * <p> This method will clear the Data Table
   */

  public void clear()
  {
    iRows = 1;
    oData = new Object[iRows][iColumns];

    for (int i=0; i<iColumns; i++)
    {
      for (int j=0; j<iRows; j++)
      {
	if (i!=0)
          oData[j][i] = new Double(0.0);
        else
          oData[j][i] = new String("");
      }
    }

    pTable.reload(iRows, oData);
    iRows = 0;
  }

  /** Method initialize()
   *  <p> This method will zero fill all the rows and columns.
   *  @param rows = The number of Rows to create.
   */

  public void initialize( int rows )
  {
    iRows = rows;

    oData = new Object[iRows][iColumns];
    for (int i=0; i<iColumns; i++)
    {
      for (int j=0; j<iRows; j++)
      {
	if (i!=0)
          oData[j][i] = new Double(0.0);
        else
          oData[j][i] = new String("");
      }
    }

    pTable.reload(iRows, oData);
  }

  /** Method setColumn()
   *  <p> This method insert the values for the Column
   *  @param iColumn = Column Number to be loaded.
   *  @param rows    = Column of Data to insert into the Computation Table.
   *  @param oRow    = The Data to be loaded in the column
   */

  public void setColumn(int iColumn, int rows, Object oRow[])
  {
    if (iRows == 0)
    {
      initialize(rows);
    }

    for (int j=0; j<iRows; j++)
    {
      oData[j][iColumn] = new Double(0.0);
      if (j<rows)
        oData[j][iColumn] = oRow[j];
    }

    pTable.reload(iRows, oData);
  }

  /** Method setRow()
   *  <p> This method insert the values for the Column
   *  @param iRow = Row Number to be loaded.
   *  @param rows = total rows
   *  @param data = The Data to be loaded in the row
   *  @param sMen = Mnemonic of curve
   */

  public void setRow(int iRow, int rows, double data[], String sMnem)
  {
    if (iRows == 0)
    {
      initialize(rows);
    }

    oData[iRow][0] = new String(sMnem);
    for (int j=1; j<iColumns; j++)
    {
      oData[iRow][j] = new Double(data[j-1]);
    }

    pTable.reload(iRows, oData);
  }

  /** Method setColumn()
   *  <p> This method insert the values for the Column
   *  @param iColumn = Column Number to be loaded.
   *  @param rows    = Column of Data to insert into the Computation Table.
   *  @param data    = The Data to be loaded in the column
   */

  public void setColumn(int iColumn, int rows, double data[])
  {
    if (iRows == 0)
    {
      initialize(rows);
    }

    for (int j=0; j<iRows; j++)
    {
      oData[j][iColumn] = new Double(data[j]);
    }

    pTable.reload(iRows, oData);
  }

  /* ===================================================================== *
   * -------------------------- GET METHODS ------------------------------ *
   * ===================================================================== */

  /** Method getColumnData()
   *  <p> This method will return the Data for the column specified.
   *  @param iCol    = The Column Data that is to be returned
   *  @return dValue = Array of double values
   */

  public double[] getColumnData(int iCol)
  {
    int    i;
    double dValue[] = null;
    Double doubleVal;

    dValue = new double[iRows];
    for (i=0; i<iRows; i++)
    {
      dValue[i] = 0.0;
    }

    for (i=0; i<iRows; i++)
    {
      try
      {
        doubleVal = (Double) oData[i][iCol];
        dValue[i] = doubleVal.doubleValue();
      }
      catch (NumberFormatException nfe)
      {
        sMessage = new String( "gridAvgTable.getColumnData(): " +
                               i + " " + nfe.getMessage() );
        JOptionPane.showMessageDialog( (Component) null,
                                       sMessage,
                                       "ERROR",
                                       JOptionPane.ERROR_MESSAGE );
      }
    }

    return (dValue);
  }

  /** Method getSelectedRow()
   *  <p> This method will return the selected row.
   *  @return iSelectedRow - Selected Row.
   */

  public int getSelectedRow() { return (pTable.getSelectedRow()); }

  /** Method getColumnCount()
   *  <p> This method will return the total number of rows in Table.
   *  @return iColumns = Total Number of Columns in Table.
   */

  public int getColumnCount() { return (iColumns); }

  /** Method getRowCount()
   *  <p> This method will return the total number of rows in Table.
   *  @return iRows = Total Number of Rows in Table.
   */

  public int getRowCount() { return (iRows); }

  /** Method getData()
   *  <p> This method will return the computed data in double
   *  @return dComputed = array of data (rows X columns)
   */

  public double[][] getData()
  {
    double dData[][];
    int rowCount,colCount;
    Double doubleVal;

    dData = new double[iRows][iColumns];
    for ( rowCount =0; rowCount < iRows; rowCount++ )
    {
      for ( colCount=0; colCount < iColumns; colCount++ )
      {
        doubleVal = (Double) oData[rowCount][colCount];
        dData[rowCount][colCount] = doubleVal.doubleValue();
      }
    }

    return (dData);
  }

  /** Method getColumnHeaders()
   * <p> This method will return the Table Column Headers
   * @return colHeaders = array of Table Column Headers
   */

  public String[][] getColumnHeaders()
  {
    String[][] colHeaders;
    colHeaders = new String[1][11];

    for ( int i=0; i < 11; i++ )
    {
      colHeaders[0][i] = new String( sColumn[i] );
    }

    return (colHeaders);
  }

  /** Method getScrollPane()
   * <p> This method will retrieve the JScrollPanel Object
   * @return JScrollPane object
   */

  public JScrollPane getScrollPane() { return (pTable.getScrollPane()); }
}

/*
 *  @version 1.1 07/06/2015
 *  @author  John Victorine
 */
