/*
 * @gridStartAppPanel.java Version 1.1 02/25/2016
 *
 * Copyright (c) 2016 Kansas Geological Survey
 * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
 * All Rights Reserved.
 */

package grid.gui;

import java.awt.*;
import java.awt.image.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;
import javax.swing.border.*;

import grid.gridStruct;           // Grid Structure
import grid.gridDataStruct;       // Grid Data Structure
import grid.gui.gridControlFrame; // Grid Control Frame

/** Class gridStartAppPanel
 *  <p> This Class Starting Panel for this web application
 *
 *  @version 1.1 02/25/2016
 *  @author  John R. Victorine
 */

public class gridStartAppPanel extends JPanel implements ActionListener
{
  // Input Variables

  private String         sID      = "";    // type of data LAB or FIELD
  private JFrame         parent   = null;  // Frame calling this panel
  private gridStruct     stStruct = null;  // Grid Structure
  private gridDataStruct stData   = null;  // Grid Data Structure

  // Global Variable

  gridControlFrame   frame    = null;

  // Global Panel Widgets

  private JButton    btn      = null;
  private JButton    btnExit  = new JButton();

  /** Constructor gridStartAppPanel( JFrame parent, gridStruct stStruct )
   *  <p> This is the Constructor for this class.
   *  @param sID      = The type of data LAB or FIELD
   *  @param parent   = the frame calling this panel
   *  @param stStruct = Grid Structure
   *  @param stData   = Grid Data Structure
   */

  public gridStartAppPanel( String sID,
                            JFrame parent,
                            gridStruct stStruct,
                            gridDataStruct stData )
  {
    try
    {
	  this.sID      = sID;
      this.parent   = parent;
      this.stStruct = stStruct;
      this.stData   = stData;

      jbInit();
    }
    catch(Exception ex)
    {
      ex.printStackTrace();
    }
  }

  /** METHOD jbInit()
   *  <p> This Method will create the Panel for this class.
   *  @throws Exception
   */

  private void jbInit() throws Exception
  {
    JPanel pnlCenter = new JPanel();
    JPanel pnlBase   = new JPanel();

    JLabel lbl       = new JLabel();

    // Build Panel

    this.setLayout( new BorderLayout() );
    this.setBackground(Color.white);

    pnlCenter.setLayout( new BorderLayout() );
    pnlCenter.setBackground(Color.white);

    btn = new JButton( createImageIcon( grid.gridStruct.BRINE_DATA) );
    btn.setBackground(Color.white);
    btn.addActionListener( this );

    lbl.setHorizontalAlignment(SwingConstants.CENTER);
    lbl.setFont(new java.awt.Font("Dialog", 1, 20));
    lbl.setBackground(Color.white);
    lbl.setText("Enter");

    pnlBase.setLayout( new GridLayout() );
    pnlBase.setBackground(Color.white);

    btnExit.setFont(new java.awt.Font("Dialog", 1, 11));
    btnExit.setText("Exit");
    btnExit.addActionListener(this);

    // Add Widgets to Panel

    this.add( pnlCenter,    BorderLayout.CENTER );
    pnlCenter.add( btn,     BorderLayout.CENTER );
    pnlCenter.add( lbl,     BorderLayout.SOUTH );

    if (parent != null)
    {
      this.add( pnlBase,    BorderLayout.SOUTH );
      pnlBase.add( btnExit, null );
    }
  }

  /** METHOD createImageIcon()
   *  <p> This Method will create the Frame for this class.
   *  @param path = the path to the image
   *  @return image icon
   */

  protected ImageIcon createImageIcon(String path)
  {
    java.net.URL imgURL = getClass().getResource(path);
    ImageIcon    image  = null;

    if (imgURL != null)
    {
      image = new ImageIcon(imgURL);
    }
    else
    {
       System.err.println("Couldn't find file: " + path);
    }

    return (image);
  }

  /* ===================================================================== *
   * ---------------------------- ACTIONS -------------------------------- *
   * ===================================================================== */

  /** Method close()
   * <p> This method will close all dialogs that are opened by this class.
   */

  public void close()
  {
    // Input Variables

    sID      = null;  // type of data LAB or FIELD
    stStruct = null;  // Grid Structure
    stData   = null;  // Grid Data Structure

    if (frame != null)
      frame.close();
    frame    = null;

    // Global Panel Widgets

    btn      = null;
    btnExit  = null;

    if (parent != null)
    {
      parent.dispose();
      parent = null;

      System.exit(0);
    }
  }

  /** METHOD actionPerformed()
   *  <p> This Method will handle all the actions within the Frame.
   *  @param event - Action Event
   */

  public void actionPerformed(ActionEvent event)
  {
    if (event.getSource() == btn)
    {
      if (frame != null)
        frame.close();
      frame    = null;

      frame = new gridControlFrame( sID, stStruct, stData );
	}

    if (event.getSource() == btnExit)
    {
	  close();
	}
  }
}

/*
 *  @version 1.1 02/25/2016
 *  @author  John Victorine
 */
