/*
 * @gridAnimationFrame.java Version 1.1 02/26/2016
 *
 * Copyright (c) 2016 Kansas Geological Survey
 * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
 * All Rights Reserved.
 */

package grid.plot;

import java.util.Observer;
import java.util.Observable;

import java.awt.*;
import java.awt.event.*;

import javax.swing.*;
import javax.swing.event.*;

import gui.guiSearchDirectoryFrame;         // GUI Search Directory Frame

import grid.plot.gridPlotMappingListStruct; // Grid Plot Mapping List Structure
import grid.plot.gridPlotAnimationFrame;    // Plot Animate Frame.

/** Class gridAnimationFrame
 *  <p> This file will display the brine Sample Animation Panel and will control
 *      the animation.
 *
 *  @version 1.1 02/26/2016
 *  @author  John R. Victorine
 */

public class gridAnimationFrame extends JFrame implements ActionListener, Observer
{
  public static final int _OFF     = 0; // Well Symbols OFF
  public static final int _ON      = 1; // Well Symbols ON

  public static final int STOP     = 0;
  public static final int PAUSE    = 1;
  public static final int RUN      = 2;

  public static final int PREVIOUS = 0;
  public static final int NEXT     = 1;

  // Input Variables

  private String                    sID    = "";
  private gridPlotMappingListStruct stPlot = null;

  // Global Frame Variables

  private Observable       notifier = null; // Observalbles Object

  private int iAction = STOP;
  private int iWells  = _ON;

  private guiSearchDirectoryFrame pSearch = null; // Search for Directory

  private String sPath = "";
  private String sName = "";

  private gridPlotAnimationFrame  pXY    = null;

  // Frame Widgets

  private JButton      btnPDF   = null;                // Create PNG Images

  private JButton      btnStop  = new JButton();       // Stop Animation Action
  private JButton      btnPause = new JButton();       // Pause Animation Action
  private JButton      btnRun   = new JButton();       // Run Animation Action

  private JButton      btnPrev  = null;                // Previous Year Action
  private JButton      btnNext  = null;                // Next Year Action

  /** Constructor gridAnimationFrame()
   *  <p> This is the Constructor for this class
   *  @param stPlot = Grid Plot Mapping List Structure
   */

  public gridAnimationFrame( String sID, gridPlotMappingListStruct stPlot )
  {
    try
    {
	  this.sID    = sID;
      this.stPlot = stPlot;

      jbInit();

      plotData();

      setButtons();
      addWindowListener( new gridAnimationFrame_WindowListener() );
    }
    catch(Exception e)
    {
      e.printStackTrace();
    }
  }

  /** Method jbInit()
   *  <p> This method will create this Panel.
   *  @throws Exception
   */

  private void jbInit() throws Exception
  {
	JPanel   pnlTop     = new JPanel();
	JPanel   pnlCenter  = new JPanel();
	JPanel   pnlBase    = new JPanel();
	JPanel   pnlPlay    = new JPanel();
	JPanel   pnlIncPlay = new JPanel();

    // Create an Observable

    notifier = new gridAnimationFrameObservable();

    // Add this Dialog to the notifier as observer

    notifier.addObserver(this);

    this.setTitle( "Plot Animation Control" );
    this.getContentPane().setLayout(new BorderLayout());

    // Top Panel

    pnlTop.setLayout(new BorderLayout());

    btnPDF = new JButton(createImageIcon(cmn.cmnStruct.PDF));
    btnPDF.setPreferredSize(new Dimension(29, 29));
    btnPDF.setToolTipText("Save all Panels Displayed as PNG Images");
    btnPDF.addActionListener(this);

    // Center Panel

    pnlCenter.setLayout(new BorderLayout());

    // Base Panel

    pnlBase.setLayout(new BorderLayout());
    pnlBase.setBackground(Color.white);

    // -- Play Panel

    btnStop.setFont(new java.awt.Font("Dialog", 1, 13));
    btnStop.setText("Stop");
    btnStop.setEnabled(false);
    btnStop.addActionListener(this);

    btnPause.setFont(new java.awt.Font("Dialog", 1, 13));
    btnPause.setText("Pause");
    btnPause.setEnabled(false);
    btnPause.addActionListener(this);

    btnRun.setFont(new java.awt.Font("Dialog", 1, 13));
    btnRun.setText("Run");
    btnRun.setEnabled(false);
    btnRun.addActionListener(this);

    // -- Increment Play Panel

    pnlIncPlay.setLayout(new BorderLayout());

    btnPrev = new JButton(createImageIcon(cmn.cmnStruct.PREVIOUS));
    btnPrev.setPreferredSize(new Dimension(27, 27));
    btnPrev.setBackground(Color.white);
    btnPrev.setToolTipText("Previous Event - Increment by event");
    btnPrev.setEnabled(false);
    btnPrev.addActionListener(this);

    btnNext = new JButton(createImageIcon(cmn.cmnStruct.NEXT));
    btnNext.setPreferredSize(new Dimension(27, 27));
    btnNext.setBackground(Color.white);
    btnNext.setToolTipText("Next Event - Increment by event");
    btnNext.setEnabled(false);
    btnNext.addActionListener(this);

	// Attach Widget to Frame

    this.getContentPane().add(pnlTop,    BorderLayout.NORTH);
    pnlTop.add(btnPDF,                   BorderLayout.WEST);

    this.getContentPane().add(pnlBase,   BorderLayout.SOUTH);
    pnlBase.add(pnlPlay,                 BorderLayout.CENTER);
    pnlPlay.add(btnStop,                 null);
    pnlPlay.add(btnPause,                null);
    pnlPlay.add(btnRun,                  null);

    pnlBase.add(pnlIncPlay,              BorderLayout.EAST);
    pnlIncPlay.add(btnPrev,              BorderLayout.WEST);
    pnlIncPlay.add(btnNext,              BorderLayout.EAST);

    // Display the Frame

//    this.setSize(new Dimension(500, 120));
    this.setSize(new Dimension(500, 160));
    Dimension d = Toolkit.getDefaultToolkit().getScreenSize();

    this.setLocation((d.width  - this.getSize().width) / 2, 10);
                     //(d.height - this.getSize().height) / 2);

    this.setResizable(true);
    this.setVisible(true);
  }

  /** METHOD createImageIcon()
   *  <p> This Method will create the Frame for this class.
   *  @param path = the path to the image
   *  @return image icon
   */

  protected ImageIcon createImageIcon(String path)
  {
    java.net.URL imgURL = getClass().getResource(path);
    ImageIcon    image  = null;

    if (imgURL != null)
    {
      image = new ImageIcon(imgURL);
    }
    else
    {
       System.err.println("Couldn't find file: " + path);
    }

    return (image);
  }

  /* ===================================================================== *
   * ------------------------- CLOSE METHODS ----------------------------- *
   * ===================================================================== */

  /** METHOD gridAnimationFrame_WindowListener()
   *  <p> This Class will handle Frame Close Action using the X Button on Frame
   */

  public class gridAnimationFrame_WindowListener extends WindowAdapter
  {
    public void windowClosing(WindowEvent e)
    {
      close();
//      System.exit(0);
    }
  }

  /** Method close()
   *  <p> deallocate memory and close out frame
   */

  public void close()
  {
	notifier = null; // Observalbles Object

    sID    = null;
    stPlot = null;

    if (pSearch != null)
      pSearch.close();
    pSearch = null;

    if (pXY != null)
      pXY.close();
    pXY = null;

    btnPDF   = null;

    btnStop  = null;
    btnPause = null;
    btnRun   = null;

    btnPrev  = null;
    btnNext  = null;

    dispose();
  }

  /* ===================================================================== *
   * -------------------------- SET METHODS ------------------------------ *
   * ===================================================================== */

  /** Method setButtons()
   *  <p> This method will enable/disable button, change colors
   */

  private void setButtons()
  {
	btnPDF.setEnabled(false);

    btnStop.setEnabled(false);
    btnPause.setEnabled(false);
    btnRun.setEnabled(false);

    btnPrev.setEnabled(false);
	btnNext.setEnabled(false);

	if (stPlot != null)
	{
	  if (stPlot.iCount > 0)
	  {
        btnStop.setEnabled(true);
        btnPause.setEnabled(true);
        btnRun.setEnabled(true);
	  }
	}

    switch (iAction)
    {
	  case STOP:
        btnStop.setBackground(new Color(255, 255, 0));
        btnPause.setBackground(new Color(180, 180, 180));
        btnRun.setBackground(new Color(180, 180, 180));
	    break;
	  case PAUSE:
	    btnPDF.setEnabled(true);

        btnStop.setBackground(new Color(180, 180, 180));
        btnPause.setBackground(new Color(255, 255, 0));
        btnRun.setBackground(new Color(180, 180, 180));

	    btnPrev.setEnabled(true);
	    btnNext.setEnabled(true);
	    break;
	  case RUN:
        btnStop.setBackground(new Color(180, 180, 180));
        btnPause.setBackground(new Color(180, 180, 180));
        btnRun.setBackground(new Color(255, 255, 0));
	    break;
	}
  }

  /* ===================================================================== *
   * ---------------------- Display Plot Frames -------------------------- *
   * ===================================================================== */

  /** Method plotData()
   *  <p> This method will build the Animation Frames and display them.
   */

  private void plotData()
  {
    if (pXY != null)
      pXY.close();
    pXY = null;

    if (stPlot != null)
    {
      pXY  = new gridPlotAnimationFrame( stPlot );
//      if (sID.equals("FIELD"))
//      {
		pXY.setWellLabel(grid.plot.gridPlotMapping.LEASE);
//	  }
	}
  }

  /* ===================================================================== *
   * -------------------------- PDF Methods ------------------------------ *
   * ===================================================================== */

  /** Method createPDF()
   *  <p> This method will create a PDF Image of Profile Plot
   */

  private void createPDF()
  {

    if (pXY != null)
    {
      pc.io.pcIO_Files.createImage( sPath, sName, pXY.getImage() );
      pc.io.pcIO_Files.createHTML( sPath, sName );
//      plot.setWellLabel(NUMBER);
//      grid.io.gridIO_Files.createImage( sPath, sName, pXY.getImage() );

//      plot.setWellLabel(iLabel);
//      grid.io.gridIO_Files.createHTML( sPath, sName, stHeaders, stGrid, st );
    }
  }

  /* ===================================================================== *
   * ---------------------------- ACTIONS -------------------------------- *
   * ===================================================================== */

  /** METHOD actionPerformed()
   *  <p> This Method will handle all the actions within the Frame.
   *  @param event - Action Event
   */

  public void actionPerformed(ActionEvent event)
  {
    if (event.getSource() == btnPDF)
    {
  	  if (sPath.length() == 0)
        sPath = grid.io.gridIO_Files.getHomeDir();

      sName   = new String( "Grid" );
      pSearch = new guiSearchDirectoryFrame(notifier, sPath, sName, ".png");
    }


	if (pXY != null)
	{
      if (event.getSource() == btnStop)
      {
	    iAction = STOP;
	    pXY.stopAnimation();
	  }

      if (event.getSource() == btnPause)
      {
  	    iAction = PAUSE;
	    pXY.pauseAnimation();
	  }

      if (event.getSource() == btnRun)
      {
	    iAction = RUN;
	    pXY.startAnimation();
	  }

      if (event.getSource() == btnPrev)
      {
		if (pXY  != null) { pXY .stepAction(PREVIOUS); }
	  }
      if (event.getSource() == btnNext)
      {
		if (pXY  != null) { pXY .stepAction(NEXT); }
	  }
	}

	setButtons();
  }

  /* ===================================================================== *
   * ---------------------- OBSERVABLE ACTIONS --------------------------- *
   * ===================================================================== */

  /** Method update()
   * <p> This method will handle the Observable Actions
   * @param obj = The Observable making the call
   * @param arg = The returned object
   */

  public void update(Observable obj, Object arg)
  {
    String sArg = new String((String) arg);

    if (sArg.equals("Directory Path Selected"))
    {
      if (pSearch != null)
      {
        sPath = new String( pSearch.getPath() );
        sName = new String( pSearch.getFile() );
      }

      createPDF();

      if (pSearch != null)
        pSearch.close();
      pSearch = null;
	}

	setButtons();
  }
}

/** CLASS gridAnimationFrameObservable()
 *  <p> This Class will handle Observable Actions when action occurs on a
 *      frame or panel
 */

class gridAnimationFrameObservable extends Observable
{
  public void notifyObservers(Object b)
  {
    setChanged();
    super.notifyObservers(b);
  }
}

/*
 *  @version 1.1 02/26/2016
 *  @author  John Victorine
 */
