/*
 * @gridPlotAnimationPanel.java Version 1.1 02/26/2016
 *
 * Copyright (c) 2016 Kansas Geological Survey
 * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
 * All Rights Reserved.
 */

package grid.plot;

import java.awt.*;
import java.awt.image.*;
import java.awt.event.*;

import javax.swing.*;
import javax.swing.event.*;

import grid.plot.gridPlotMappingListStruct; // Grid Plot Mapping List Structure

/** Class gridPlotAnimationPanel
 *  <p> This Class will create the Stiff Plot.
 *
 *  @version 1.1 02/26/2016
 *  @author  John R. Victorine
 */

public class gridPlotAnimationPanel extends JPanel
{
  public static final int _OFF   = 0;
  public static final int _ON    = 1;

  public static final int PREVIOUS = grid.plot.gridAnimationFrame.PREVIOUS;
  public static final int NEXT     = grid.plot.gridAnimationFrame.NEXT;

  // Input Variables

  private gridPlotMappingListStruct stPlot  = null;

  // Global Variables

  private int   iLabel    = grid.plot.gridPlotMapping.API;
  private int   iCurrent  = 0;    // Current image plotted

  private int   iPicture  = 0;    // Total Number of Sample Plot Images loaded
  private Image picture   = null; // Array of Sample Plot Images

  private int   delay     = 1000; // milliseconds (1000 = 1 Second)
//  private int   delay     = 500; // milliseconds (1000 = 1 Second)
  private Timer timer     = null; // Timer for Animation

  /** Constructor gridPlotAnimationPanel()
   *  <p> This is the Constructor for this class.
   *  @param stPlot = Grid Plot Mapping List Structure
   */

  public gridPlotAnimationPanel( gridPlotMappingListStruct stPlot )
  {
    try
    {
      this.stPlot = stPlot;

      init();
    }
    catch(Exception e)
    {
      e.printStackTrace();
    }
  }

  /** Method init()
   *  <p> This method will initialize and create the images for animation
   */

  public void init()
  {
	// Create the Images for animation

    if (stPlot != null)
    {
      if (stPlot.iCount > 0)
      {
        for (int i=0; i<stPlot.iCount; i++)
        {
	      iPicture++;
	    }
      }

      // Set up a timer that calls this object's action handler.

      initTimer();
    }
  }

  /** Method paint()
   *  Class Paint Method
   *  @param g = graphics object
   */

  public void paint(Graphics g)
  {
    super.paintComponent(g);
    Graphics2D g2 = (Graphics2D) g;
/*
for (int i=0; i<stPlot.stItem[iCurrent].iWells; i++)
  System.out.println(
    stPlot.stItem[iCurrent].dX[i]+" "+
    stPlot.stItem[iCurrent].dY[i]+" "+
    stPlot.stItem[iCurrent].dZR[i]+" "+
    stPlot.stItem[iCurrent].dZG[i]+" "+
    stPlot.stItem[iCurrent].dZB[i]+" "+
    stPlot.stItem[iCurrent].status[i]+" "+
    stPlot.stItem[iCurrent].sAPI[i]+" "+
    stPlot.stItem[iCurrent].sKID[i]+" "+ // Well KID;
    stPlot.stItem[iCurrent].sLease[i]);
*/

    picture = grid.plot.gridPlotMappingImage.makePlotImage( stPlot.stItem[iCurrent], iLabel );

    if (picture != null)
    {
      g2.drawImage(picture, 0, 0, this);
    }
    else
      System.out.println("Picture: "+iCurrent+" Does NOT Exist");

  }

  /** Method getImage()
   * <p> This method will convert this plot to a buffered image
   * @return image = profile plot buffered image
   */

  public BufferedImage getImage()
  {
    BufferedImage image = null;
    int w = 1250;
    int h = 700;

    picture = grid.plot.gridPlotMappingImage.makePlotImage( stPlot.stItem[iCurrent], iLabel );

    if (picture != null)
    {
      image = new BufferedImage( w, h, BufferedImage.TYPE_INT_RGB );

      Graphics2D g2 = image.createGraphics();
      g2.setColor( Color.white );
      g2.fillRect( 0, 0, w, h );

      g2.drawImage(picture, 0, 0, this);

      g2.dispose();
    }

    return (image);
  }

  /* ================================================================== *
   * ------------------------ CLOSE METHODS --------------------------- *
   * ================================================================== */

  /** Method close()
   *  <p> deallocate memory and close out frame
   */

  public void close()
  {
    // Input Variables

    stPlot  = null; // Earthquake Plot Data List Structure

    // Global Variables

    iCurrent = 0;    // Current image plotted
    picture  = null;
    iPicture = 0;    // Total Number of Sample Plot Images loaded
    timer    = null; // Timer for Animation
  }

  /* ================================================================== *
   * ------------------------- SET METHODS ---------------------------- *
   * ================================================================== */

  /** Method setWellLabel()
   *  <p> This method will set the type of label to display with the well symbols
   */

  public void setWellLabel(int iLabel)
  {
	this.iLabel = iLabel;
  }

  /* ===================================================================== *
   * ----------------------- ANIMATION ACTIONS --------------------------- *
   * ===================================================================== */

  /** Method initTimer()
   *  <p> this method will initialize the timer
   */

  private void initTimer()
  {
    timer = new Timer(delay, new animateAction());
    timer.setInitialDelay(0);
    timer.setCoalesce(true);
  }

  /** Method startAnimation() throws Exception
   *  <p> Starts the timer that generates action events
   * @throws Exception - exception starting the timer
   */

  public void startAnimation() throws Exception
  {
    if (!timer.isRunning())
    {
      timer.start();
    }
  }

  /** Method pauseAnimation()
   *  <p> Stops the timer that generate action events
   */

  public void pauseAnimation() throws Exception
  {
    if (timer.isRunning())
    {
      timer.stop();
    }
  }

  /** Method stopAnimation() throws Exception
   *  <p> Stops the timer that generate action events
   *      and resets the current image number to 0
   * @throws Exception - exception stopping the timer
   */

  public void stopAnimation() throws Exception
  {
    if (timer.isRunning())
    {
      timer.stop();
      setCurrent(0);
    }
  }

  /** Method stepAction()
   *  <p> This method will issue a step action to the plot
   */

  public void stepAction(int iStep)
  {
	switch (iStep)
	{
	  case PREVIOUS:
        if (iCurrent == 0)
          setCurrent(iPicture-1);
        else
          setCurrent(iCurrent-1);
	    break;

	  case NEXT:
        if (iCurrent < iPicture-1)
          setCurrent(iCurrent+1);
        else
          setCurrent(0);
	    break;
	}
  }

  /** Class animateAction()
   *  <p> This method will perform the changes in the displayed image
   */

  class animateAction implements ActionListener
  {
    public void actionPerformed(ActionEvent evt)
    {
      if (iCurrent < iPicture-1)
        setCurrent(iCurrent+1);
      else
        setCurrent(0);
    }
  }

  /** Method setCurrent(int iValue)
   *  <p> Sets the current image number.
   *
   *  @param iValue - image to be
   */

  private void setCurrent(int iValue)
  {
    this.iCurrent = iValue;
    repaint();
  }
}

/*
 *  @version 1.1 02/26/2016
 *  @author  John Victorine
 */
