/*
 * @BriggsCube.java Version 1.1 07/29/2015
 *
 * Copyright (c) 2013 Kansas Geological Survey
 * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
 * All Rights Reserved.
 */

package plot;

import java.awt.*;
import java.awt.image.*;
import java.awt.geom.*;
import java.awt.Graphics2D.*;
import java.awt.event.*;

/** Class BriggsCube
 *  <p> This class will create a Briggs Cube for the colorlith
 *
 *  @version 1.1 07/29/2015
 *  @author  John R. Victorine
 */

public class BriggsCube extends Canvas
{
  // Input Variables

  private int    iXPos      = 0;
  private int    iYpos      = 0;

  private int    iRed       = -1;
  private int    iGreen     = -1;
  private int    iBlue      = -1;

  // Global Variables

  private int    iReverse[]  = { 1, 1, 1 };
  private String sLabel[]    = { "", "", "" };
  private String sLimits[][] = {{ "", "" },
                                { "", "" },
                                { "", "" }};
  // Plot Dimensions

  private int iXBegin = 80;  // Left Edge of Plot Area
  private int iYBegin = 80;  // Top Edge of Plot Area
  private int iWidth  = 500; // Width of Plot Area
  private int iHeight = 500; // Height of Plot Area

  /** Constructor BriggsCube()
   *  <p> This is the Constructor for this class.
   */

  public BriggsCube( int    iXPos,  int    iYPos,
                     int    iWidth, int    iHeight,
	                 int    iRed,   int    iGreen, int iBlue,
                     double dMinR,  double dMaxR,
                     double dMinG,  double dMaxG,
                     double dMinB,  double dMaxB )
  {
	this.iXBegin = iXPos;
	this.iYBegin = iYPos;

    this.iWidth  = iWidth;
    this.iHeight = iHeight;

	this.iRed    = iRed;
	this.iGreen  = iGreen;
	this.iBlue   = iBlue;

    if (iRed > -1)
    {
	  sLimits[0][0] = new String("" + dMinR);
	  sLimits[0][1] = new String("" + dMaxR);
	  sLabel[0]     = new String( fluid.fluidStandardTools.CURVES[iRed][1] );
	}

    if (iGreen > -1)
    {
	  sLimits[1][0] = new String("" + dMinG);
	  sLimits[1][1] = new String("" + dMaxG);
	  sLabel[1]     = new String( fluid.fluidStandardTools.CURVES[iGreen][1] );
	}

    if (iBlue > -1)
    {
	  sLimits[2][0] = new String("" + dMinB);
	  sLimits[2][1] = new String("" + dMaxB);
	  sLabel[2]     = new String( fluid.fluidStandardTools.CURVES[iBlue][1] );
	}
  }

  /* =============================================================== *
   * ----------------------- DELETE METHODS ------------------------ *
   * =============================================================== */

  /** Method close()
   * <p> This method will set strings and arrays to null so Java can
   *     automatically clear memory
   */

  public void close()
  {
    iReverse = null;
    sLabel   = null;
    sLimits  = null;
  }

  /* ================================================================== *
   * -------------------------- DRAW METHODS -------------------------- *
   * ================================================================== */

  /** Method drawColorlith(Graphics g)
   * <p> This method will draw the Colorlith Cube
   * @param g = Graphics Parameter.
   */

  public void drawColorlith(Graphics g)
  {
    int         w     = 20;
    int         iX    = iXBegin+iWidth;
    int         iY    = iYBegin+iHeight;
    int         iXPos = 0;
    String      sText = "";
    int         len   = 0;
    Font        fsb   = new Font("Serif", Font.BOLD, 11);
    FontMetrics fsbm  = g.getFontMetrics(fsb);

    g.setFont( fsb );
    g.setColor(Color.black);

    drawRow( g, iX, iY-120, w, 255 );
    drawRow( g, iX, iY-60,  w, 128 );
    drawRow( g, iX, iY,     w,   0 );

    // Draw Z-Axis

    if (iReverse[2] == 0)
      sText = sLimits[2][1]; //"" + LIMITS[stPlot.iColor[2]][1];
    else
      sText = sLimits[2][0]; //"" + LIMITS[stPlot.iColor[2]][0];

    len   = sText.length();
    iXPos = iX - 70;
    g.drawString(sText, iXPos, iY-80 );

    sText = sLabel[2]; //"" + MNEMONICS[stPlot.iColor[2]];
    len   = sText.length();
    iXPos = iX - 70;
    g.drawString(sText, iXPos, iY-20 );

    if (iReverse[2] == 0)
      sText = sLimits[2][0]; //"" + LIMITS[stPlot.iColor[2]][0];
    else
      sText = sLimits[2][1]; //"" + LIMITS[stPlot.iColor[2]][1];

    len   = sText.length();
    iXPos = iX - 70;
    g.drawString(sText, iXPos, iY+40 );

    // Draw Y-Axis

    if (iReverse[0] == 0)
      sText = sLimits[0][1]; //"" + LIMITS[stPlot.iColor[0]][1];
    else
      sText = sLimits[0][0]; //"" + LIMITS[stPlot.iColor[0]][0];

    len   = sText.length();
    iXPos = iX - 40;
    g.drawString(sText, iXPos, iY+65 );

    sText = sLabel[0]; //"" + MNEMONICS[stPlot.iColor[0]];
    len   = sText.length();
    iXPos = iX; // - 10;
    g.drawString(sText, iXPos, iY+65 );

    if (iReverse[0] == 0)
      sText = sLimits[0][0]; //"" + LIMITS[stPlot.iColor[0]][0];
    else
      sText = sLimits[0][1]; //"" + LIMITS[stPlot.iColor[0]][1];

    len   = sText.length();
    iXPos = iX + 35;
    g.drawString(sText, iXPos, iY+65 );

    // Draw X-Axis

    if (iReverse[1] == 0)
      sText = sLimits[1][1]; //"" + LIMITS[stPlot.iColor[1]][1];
    else
      sText = sLimits[1][0]; //"" + LIMITS[stPlot.iColor[1]][0];

    len   = sText.length();
    iXPos = iX + 65;
    g.drawString(sText, iXPos, iY+45 );

    sText = sLabel[1]; //"" + MNEMONICS[stPlot.iColor[1]];

    len   = sText.length();
    iXPos = iX + 75;
    g.drawString(sText, iXPos, iY+30 );

    if (iReverse[1] == 0)
      sText = sLimits[1][0]; //"" + LIMITS[stPlot.iColor[1]][0];
    else
      sText = sLimits[1][1]; //"" + LIMITS[stPlot.iColor[1]][1];

    len   = sText.length();
    iXPos = iX + 85;
    g.drawString(sText, iXPos, iY+15 );
  }

  /** Method drawCube(Graphics g, int x, int y, int side)
   *
   * @param g    = Graphics Parameter.
   * @param x    = x-coor of top left corner of forward square face
   * @param y    = y-coor of top left corner of forward square face
   * @param side = width & height of square
   * @param rr   = Red Color value
   * @param gg   = Green Color value
   * @param bb   = Blue Color value
   */

  public void drawCube( Graphics g, int x,  int y,  int side,
                                    int rr, int gg, int bb)
  {
    int ix[] = null;
    int iy[] = null;

    g.setColor( new Color( rr, gg, bb ) );
    g.fillRect( x, y, side, side );

    g.setColor( Color.black );
    g.drawRect( x, y, side, side );

    ix = new int[4];
    iy = new int[4];

    ix[0] = x;
    iy[0] = y;

    ix[1] = x+side/2;
    iy[1] = y-side/2;

    ix[2] = x+side/2 + side;
    iy[2] = y-side/2;

    ix[3] = x + side;
    iy[3] = y;

    g.setColor( new Color( rr, gg, bb ) );
    g.fillPolygon(ix, iy, 4);

    g.setColor( Color.black );
    g.drawPolygon(ix, iy, 4);

    for (int i=0; i<4; i++)
    {
      ix[i] = 0;
      iy[i] = 0;
    }

    ix[0] = x + side;
    iy[0] = y;

    ix[1] = x+side/2 + side;
    iy[1] = y-side/2;

    ix[2] = x+side/2 + side;
    iy[2] = y-side/2 + side;

    ix[3] = x + side;
    iy[3] = y + side;

    g.setColor( new Color( rr, gg, bb ) );
    g.fillPolygon(ix, iy, 4);

    g.setColor( Color.black );
    g.drawPolygon(ix, iy, 4);
  }

  /** Method drawRow(Graphics g, int bb)
   * <p> This method will draw the Rhomaa-Umaa Legend
   * @param g     = Graphics Parameter.
   * @param iX    = Starting X position
   * @param iY    = Starting Y position
   * @param side  = Side width of individual cube
   * @param bb    = Blue Color value
   */

  public void drawRow(Graphics g, int iX, int iY, int side, int bb)
  {
    int XStart = iX;
    int w      = side;

    drawCube( g, iX, iY, w, 255, 0, bb );

    iX = iX + w + w/4;
    drawCube( g, iX, iY, w, 128, 0, bb );

    iX = iX + w + w/4;
    drawCube( g, iX, iY, w,   0, 0, bb );

    iX = XStart - ( w/2 + 4 );
    iY = iY     + w/2 + 4;

    drawCube( g, iX, iY, w, 255, 128, bb );

    iX = iX + w + w/4;
    drawCube( g, iX, iY, w, 128, 128, bb );

    iX = iX + w + w/4;
    drawCube( g, iX, iY, w,   0, 128, bb );

    iX = XStart - 2 * ( w/2 + 4 );
    iY = iY     + w/2 + 4;

    drawCube( g, iX, iY, w, 255, 255, bb );

    iX = iX + w + w/4;
    drawCube( g, iX, iY, w, 128, 255, bb );

    iX = iX + w + w/4;
    drawCube( g, iX, iY, w,   0, 255, bb );
  }

  /** Method draw()
   *  <p> This method will create the Linear Plot.
   *  @param g - Graphics pointer.
   */

  public void draw(Graphics g)
  {
    drawColorlith(g); // Draw the Colorlith Color Cube
  }

  /** Method paint()
   *  <p> This method will create the Linear Plot.
   *  @param g - Graphics pointer.
   */

  public void paint(Graphics g)
  {
    draw(g);
  }
}

/*
 *  @version 1.1 07/29/2015
 *  @author  John Victorine
 */
